[PATCH 49/67] upl: Correct name of upl-images

Simon Glass sjg at chromium.org
Wed Jan 1 23:09:35 CET 2025


The spec originally had both singular and plural versions of this node,
but has settled on plural. Update U-Boot to match.

Signed-off-by: Simon Glass <sjg at chromium.org>
---

 boot/upl_read.c  | 4 ++--
 boot/upl_write.c | 8 ++++----
 include/upl.h    | 4 ++--
 3 files changed, 8 insertions(+), 8 deletions(-)

diff --git a/boot/upl_read.c b/boot/upl_read.c
index fe48ae31ffb..1b6290ffb1c 100644
--- a/boot/upl_read.c
+++ b/boot/upl_read.c
@@ -302,7 +302,7 @@ static int decode_upl_params(struct upl *upl, ofnode options)
 }
 
 /**
- * decode_upl_images() - Decode /options/upl-image nodes
+ * decode_upl_images() - Decode /options/upl-images nodes
  *
  * @node: /options node in which to look for the node
  * Return 0 if OK, -ve on error
@@ -312,7 +312,7 @@ static int decode_upl_images(struct upl *upl, ofnode options)
 	ofnode node, images;
 	int ret;
 
-	images = ofnode_find_subnode(options, UPLN_UPL_IMAGE);
+	images = ofnode_find_subnode(options, UPLN_UPL_IMAGES);
 	if (!ofnode_valid(images))
 		return log_msg_ret("img", -EINVAL);
 	log_debug("decoding '%s'\n", ofnode_get_name(images));
diff --git a/include/upl.h b/include/upl.h
index a4ed24edbb8..dd43e8e8529 100644
--- a/include/upl.h
+++ b/include/upl.h
@@ -30,8 +30,8 @@ struct unit_test_state;
 #define UPLP_ADDR_WIDTH		"addr-width"
 #define UPLP_ACPI_NVS_SIZE	"acpi-nvs-size"
 
-#define UPLPATH_UPL_IMAGE	"/options/upl-image"
-#define UPLN_UPL_IMAGE		"upl-image"
+#define UPLPATH_UPL_IMAGES	"/options/upl-images"
+#define UPLN_UPL_IMAGES		"upl-images"
 #define UPLN_IMAGE		"image"
 #define UPLP_FIT		"fit"
 #define UPLP_CONF_OFFSET	"conf-offset"
diff --git a/boot/upl_write.c b/boot/upl_write.c
index a1ecb809cbc..9702ef91930 100644
--- a/boot/upl_write.c
+++ b/boot/upl_write.c
@@ -268,18 +268,18 @@ static int add_upl_params(const struct upl *upl, ofnode options)
 }
 
 /**
  * add_upl_image() - Add /options/upl-image nodes and properties to the tree
  *
  * @upl: UPL state
  * @node: /options node to add to
  * Return 0 if OK, -ve on error
  */
-static int add_upl_image(const struct upl *upl, ofnode options)
+static int add_upl_images(const struct upl *upl, ofnode options)
 {
 	ofnode node;
 	int ret, i;
 
-	ret = ofnode_add_subnode(options, UPLN_UPL_IMAGE, &node);
+	ret = ofnode_add_subnode(options, UPLN_UPL_IMAGES, &node);
 	if (ret)
 		return log_msg_ret("img", ret);
 
@@ -606,7 +606,7 @@ int upl_write_handoff(const struct upl *upl, ofnode root, bool skip_existing)
 	if (ret)
 		return log_msg_ret("ad1", ret);
 
-	ret = add_upl_image(upl, options);
+	ret = add_upl_images(upl, options);
 	if (ret)
 		return log_msg_ret("ad2", ret);
 
@@ -268,18 +268,18 @@ static int add_upl_params(const struct upl *upl, ofnode options)
 
 /**
- * add_upl_image() - Add /options/upl-image nodes and properties to the tree
+ * add_upl_images() - Add /options/upl-images nodes and properties to the tree
  *
  * @upl: UPL state
-- 
2.43.0



More information about the U-Boot mailing list